#include "circuitbuilder.h"

#include <QProcess>
#include <QImage>
#include <QStringList>
#include <QFileInfo>
#include <QDebug>
#include <KStandardDirs>

CircuitBuilder::CircuitBuilder(const QString& interpreter)
  : QObject()
{
  if (interpreter.isEmpty())
	setPicInterpreter(KStandardDirs::locateLocal("data", "cirkuit/build/cctdpic", false));
  else
    setPicInterpreter(interpreter);
}

void CircuitBuilder::build(const KUrl& url)
{
  buildProcess = new QProcess;
  
  QFileInfo fileInfo(url.path());
  QStringList args;
  args << fileInfo.absolutePath() + "/" + fileInfo.baseName();
  qDebug() << "ARG: " + fileInfo.baseName();
  
  connect(buildProcess, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(processFinished()));
  tempFileUrl = fileInfo.absolutePath() + "/" + fileInfo.baseName();
  buildProcess->start(mPicInterpreter, args);
}

void CircuitBuilder::processFinished()
{
  QImage image(tempFileUrl.path() + ".png");
  qDebug() << "OUTPUT: " + buildProcess->readAllStandardOutput();
  qDebug() << "OUTPUT: " + buildProcess->readAllStandardError();
  qDebug() << "PIC: " + tempFileUrl.path() + ".png";
  qDebug() << "BUILT";
  emit buildFinished();
  emit previewBuilt(image);
}

QString CircuitBuilder::epsFilePath() const
{
  return tempFileUrl.path() + ".eps";
}

QString CircuitBuilder::pdfFilePath() const
{
  return tempFileUrl.path() + ".pdf";
}

QString CircuitBuilder::pngFilePath() const
{
  return tempFileUrl.path() + ".png";
}

QString CircuitBuilder::pstFilePath() const
{
  return tempFileUrl.path() + ".pst";
}

